gitops

package
v0.0.0-...-39d9800 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 30, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Available

func Available() error

Types

type Exec

type Exec struct{}

runs sequentially with direct stdout and no remote fan-out

func (Exec) Remotes

func (Exec) Remotes(_ int) int

func (Exec) Run

func (Exec) Run(p Params) error

type Fetch

type Fetch struct{}

func (Fetch) Remotes

func (Fetch) Remotes(n int) int

func (Fetch) Run

func (Fetch) Run(p Params) error

type Init

type Init struct{}

func (Init) Remotes

func (Init) Remotes(_ int) int

func (Init) Run

func (Init) Run(p Params) error

type Op

type Op interface {
	Remotes(n int) int
	Run(p Params) error
}

remotes returns the number of display lines needed per repo slot 0 = exec sequentially 1 = origin only n = all remotes

type Params

type Params struct {
	RunCtx context.Context
	Path   string
	Ctx    *workspace.Context
	Disp   Reporter
	Slot   int
	Sem    chan struct{} // bounds concurrent remote operations
	Force  bool
	Args   []string
}

type Pull

type Pull struct{}

func (Pull) Remotes

func (Pull) Remotes(_ int) int

func (Pull) Run

func (Pull) Run(p Params) error

type Push

type Push struct{}

func (Push) Remotes

func (Push) Remotes(n int) int

func (Push) Run

func (Push) Run(p Params) error

type Reporter

type Reporter interface {
	Repo(slot int, msg string)
	Remote(slot, j int, msg string)
	Output(slot, j int, msg string)
	Error(slot int, msg string)
	ErrorRemote(slot, j int, msg string)
	ErrorOutput(slot, j int, msg string)
	Clear(slot int)
	Finish()
}

Source Files

  • common.go
  • exec.go
  • fetch.go
  • init.go
  • op.go
  • pull.go
  • push.go

Jump to